@@ -1,14 +1,15 @@
 import getpass
-import re
-import shlex
 import socket
-from pathlib import Path
+from pathlib import Path, PurePosixPath
+from typing import List
 from unittest import mock
 from unittest.mock import call
 
 import pytest
+
 from antareslauncher.remote_environnement.iremote_environment import (
-    GetJobStateError,
+    GetJobStateErrorException,
+    GetJobStateOutputException,
     KillJobErrorException,
     NoLaunchScriptFoundException,
     NoRemoteBaseDirException,
@@ -30,12 +31,15 @@ class TestRemoteEnvironmentWithSlurm:
 
     Test the get_all_job_state_flags() method:
 
-    2 given a study the output obtained from the SLURM command should be correctly interpreted (different tests should be
-     created, one for each treated state): the return values of the methods should be correct
+    2 given a study the output obtained from the SLURM command should be correctly interpreted
+      (different tests should be created, one for each treated state): the return values
+      of the methods should be correct
 
-    3 given a study an exception should be raised (to be created in iremote_environment.py) if the execute_command fails
+    3 given a study an exception should be raised (to be created in `iremote_environment.py`)
+      if the execute_command fails
 
-    4 given a study where study.submitted is not True we should define a return value (for example (false, false, false))
+    4 given a study where `study.submitted` is not True we should define a return value
+      (for example (false, false, false))
 
     5 given a study, if execute_command return an error then an exception should be raised
 
@@ -43,7 +47,8 @@ class TestRemoteEnvironmentWithSlurm:
     """
 
     @pytest.fixture(scope="function")
-    def study(self):
+    def study(self) -> StudyDTO:
+        """Dummy Study Data Transfer Object (DTO)"""
         return StudyDTO(
             time_limit=60,
             path="study path",
@@ -55,7 +60,8 @@ class TestRemoteEnvironmentWithSlurm:
         )
 
     @pytest.fixture(scope="function")
-    def remote_env(self):
+    def remote_env(self) -> RemoteEnvironmentWithSlurm:
+        """SLURM remote environment (Mock)"""
         remote_home_dir = "remote_home_dir"
         connection = mock.Mock()
         connection.home_dir = remote_home_dir
@@ -114,7 +120,7 @@ class TestRemoteEnvironmentWithSlurm:
         self,
     ):
         # given
-        remote_home_dir = "/applis/antares/"
+        remote_home_dir = "/applications/antares/"
         connection = mock.Mock()
         connection.home_dir = remote_home_dir
         connection.make_dir = mock.Mock(return_value=True)
@@ -157,6 +163,7 @@ class TestRemoteEnvironmentWithSlurm:
         # then
         assert remote_env.get_queue_info() == "error"
 
+    # noinspection SpellCheckingInspection
     @pytest.mark.unit_test
     def test_kill_remote_job_execute_scancel_command(self, remote_env):
         job_id = 42
@@ -194,7 +201,7 @@ class TestRemoteEnvironmentWithSlurm:
             input_zipfile_name=Path(study.zipfile_path).name,
             time_limit=1,
             n_cpu=study.n_cpu,
-            antares_version=int(study.antares_version or "0"),
+            antares_version=study.antares_version,
             run_mode=study.run_mode,
             post_processing=study.post_processing,
             other_options="",
@@ -228,487 +235,208 @@ class TestRemoteEnvironmentWithSlurm:
             remote_env.submit_job(study)
 
     @pytest.mark.unit_test
-    def test_when_submit_job_is_called_and_receives_submitted_420_returns_job_id_420(
+    def test_when_check_job_state_is_called_then_execute_command_is_called_with_correct_command(
         self, remote_env, study
     ):
-        # when
-        output = "Submitted 420"
-        error = None
+        # given
+        output = "output"
+        error = ""
+        study.submitted = True
+        study.job_id = 42
         remote_env.connection.execute_command = mock.Mock(return_value=(output, error))
+        # when
+        remote_env.get_job_state_flags(study)
         # then
-        assert remote_env.submit_job(study) == 420
+        # noinspection SpellCheckingInspection
+        expected_command = (
+            f"sacct -j {study.job_id} -n --format=state | head -1 "
+            + "| awk -F\" \" '{print $1}'"
+        )
+        remote_env.connection.execute_command.assert_called_with(expected_command)
 
     @pytest.mark.unit_test
-    def test_when_submit_job_is_called_and_receives_error_then_exception_is_raised(
+    def test_given_submitted_study__when_check_job_state_gets_empty_output_it_tries_5_times_then_raises_exception(
         self, remote_env, study
     ):
-        # when
+        # given
         output = ""
-        error = "error"
+        error = ""
+        study.submitted = True
+        study.job_id = 42
+        # when
         remote_env.connection.execute_command = mock.Mock(return_value=(output, error))
         # then
-        with pytest.raises(SubmitJobErrorException):
-            remote_env.submit_job(study)
-
-    # noinspection SpellCheckingInspection
-    @pytest.mark.unit_test
-    def test_get_job_state_flags__scontrol_failed(self, remote_env, study):
-        study.job_id = 42
-        output, error = "", "invalid entity:XXX for keyword:show"
-        remote_env.connection.execute_command = mock.Mock(return_value=(output, error))
-        with pytest.raises(GetJobStateError, match=re.escape(error)) as ctx:
+        with pytest.raises(GetJobStateOutputException):
             remote_env.get_job_state_flags(study)
-        assert output in str(ctx.value)
-        command = f"scontrol show job {study.job_id}"
-        remote_env.connection.execute_command.assert_called_once_with(command)
+        tries_number = remote_env.connection.execute_command.call_count
+        assert tries_number == 5
 
-    # noinspection SpellCheckingInspection
     @pytest.mark.unit_test
-    def test_get_job_state_flags__scontrol_dead_job(self, remote_env, study):
+    def test_given_a_submitted_study_when_execute_command_returns_an_error_then_an_exception_is_raised(
+        self, remote_env, study
+    ):
+        # given
+        output = "output"
+        error = "error"
+        study.submitted = True
         study.job_id = 42
-        job_state = "RUNNING"
-        args = [
-            "sacct",
-            f"--jobs={study.job_id}",
-            f"--name={study.name}",
-            "--format=JobID,JobName,State",
-            "--parsable2",
-            "--delimiter=,",
-            "--noheader",
-        ]
-        command = " ".join(shlex.quote(arg) for arg in args)
-
-        # noinspection SpellCheckingInspection
-        def execute_command_mock(cmd: str):
-            if cmd == f"scontrol show job {study.job_id}":
-                return "", "Invalid job id specified"
-            if cmd == command:
-                return f"{study.job_id},{study.name},{job_state}", None
-            assert False, f"Unknown command: {cmd}"
-
-        remote_env.connection.execute_command = execute_command_mock
-        actual = remote_env.get_job_state_flags(study)
-        assert actual == (True, False, False)
-
-    # noinspection SpellCheckingInspection
-    @pytest.mark.unit_test
-    def test_get_job_state_flags__scontrol_nominal(self, remote_env, study):
-        study.job_id = 42
-        job_state = "RUNNING"
-        output, error = f"JobState={job_state}", None
+        # when
         remote_env.connection.execute_command = mock.Mock(return_value=(output, error))
-        actual = remote_env.get_job_state_flags(study)
-        assert actual == (True, False, False)
+        # then
+        with pytest.raises(GetJobStateErrorException):
+            remote_env.get_job_state_flags(study)
 
     # noinspection SpellCheckingInspection
     @pytest.mark.unit_test
-    def test_get_job_state_flags__scontrol_non_parsable(self, remote_env, study):
+    @pytest.mark.parametrize(
+        "output,expected_started, expected_finished, expected_with_error",
+        [
+            ("PENDING", False, False, False),
+            ("RUNNING", True, False, False),
+            ("CANCELLED BY DUMMY", True, True, True),
+            ("TIMEOUT", True, True, True),
+            ("COMPLETED", True, True, False),
+            ("FAILED DUMMYWORD", True, True, True),
+        ],
+    )
+    def test_given_state_when_get_job_state_flags_is_called_then_started_and_finished_and_with_error_are_correct(
+        self,
+        remote_env,
+        study,
+        output,
+        expected_started,
+        expected_finished,
+        expected_with_error,
+    ):
+        # given
+        error = ""
+        study.submitted = True
         study.job_id = 42
-        output, error = "Blah!Blah!", None
         remote_env.connection.execute_command = mock.Mock(return_value=(output, error))
-        with pytest.raises(GetJobStateError, match="non-parsable output") as ctx:
-            remote_env.get_job_state_flags(study)
-        assert output in str(ctx.value)
-        command = f"scontrol show job {study.job_id}"
-        remote_env.connection.execute_command.assert_called_once_with(command)
+        # when
+        (
+            started,
+            finished,
+            with_error,
+        ) = remote_env.get_job_state_flags(study)
+        # then
+        assert started is expected_started
+        assert finished is expected_finished
+        assert with_error is expected_with_error
 
     @pytest.mark.unit_test
-    def test_get_job_state_flags__sacct_bad_output(self, remote_env, study):
-        study.job_id = 42
-        args = [
-            "sacct",
-            f"--jobs={study.job_id}",
-            f"--name={study.name}",
-            "--format=JobID,JobName,State",
-            "--parsable2",
-            "--delimiter=,",
-            "--noheader",
-        ]
-        command = " ".join(shlex.quote(arg) for arg in args)
+    @pytest.mark.parametrize(
+        "remote_files, local_files",
+        [
+            pytest.param(
+                # list of files in the remote server
+                [
+                    "antares-err-999999999.txt",
+                    "antares-out-999999999.txt",
+                    "0372c064-66db-4dd6-a05f-74f0753340b4_job_data_999999999.txt",
+                    "antares-err-123456789.txt",
+                    "antares-out-123456789.txt",
+                    "364ef7a8-e110-4a3c-a345-58640c5885b1_job_data_123456789.txt",
+                ],
+                # expected list of downloaded files
+                [
+                    "antares-err-999999999.txt",
+                    "antares-out-999999999.txt",
+                ],
+                # expected return value: list of downloaded files
+                id="nominal-case",
+            ),
+            pytest.param([], [], id="no-log-file-OK"),
+            pytest.param([], [], id="no-log-file-ERROR"),
+        ],
+    )
+    def test_download_logs(
+        self,
+        remote_env,
+        study,
+        remote_files: List[str],
+        local_files: List[str],
+    ):
+        # given
+        study.job_id = 999999999
+        study.job_log_dir = "/path/to/LOGS"
+        downloaded = [Path(study.job_log_dir).joinpath(f) for f in local_files]
+        remote_env.connection.download_files = mock.Mock(return_value=downloaded)
 
-        # the output of `sacct` is not: JobID,JobName,State
-        output = "the sun is shining"
+        # when
+        actual = remote_env.download_logs(study)
 
-        # noinspection SpellCheckingInspection
-        def execute_command_mock(cmd: str):
-            if cmd == f"scontrol show job {study.job_id}":
-                return "", "Invalid job id specified"
-            if cmd == command:
-                return output, None
-            assert False, f"Unknown command: {cmd}"
+        # then
+        assert actual == downloaded
 
-        remote_env.connection.execute_command = execute_command_mock
-
-        with pytest.raises(GetJobStateError, match="non-parsable output") as ctx:
-            remote_env.get_job_state_flags(study)
-        assert output in str(ctx.value)
-
-    # noinspection SpellCheckingInspection
-    @pytest.mark.unit_test
-    def test_get_job_state_flags__sacct_call_fails(self, remote_env, study):
-        study.job_id = 42
-        args = [
-            "sacct",
-            f"--jobs={study.job_id}",
-            f"--name={study.name}",
-            "--format=JobID,JobName,State",
-            "--parsable2",
-            "--delimiter=,",
-            "--noheader",
-        ]
-        command = " ".join(shlex.quote(arg) for arg in args)
-
-        # noinspection SpellCheckingInspection
-        def execute_command_mock(cmd: str):
-            if cmd == f"scontrol show job {study.job_id}":
-                return "", "Invalid job id specified"
-            if cmd == command:
-                return None, "an error occurs"
-            assert False, f"Unknown command: {cmd}"
-
-        remote_env.connection.execute_command = execute_command_mock
-        with pytest.raises(GetJobStateError, match="an error occurs"):
-            remote_env.get_job_state_flags(study, attempts=2, sleep_time=0.1)
-        remote_env.connection.execute_command.mock_calls = [
-            call(command),
-            call(command),
+        src_dir = PurePosixPath(remote_env.remote_base_path)
+        dst_dir = Path(study.job_log_dir)
+        assert remote_env.connection.download_files.mock_calls == [
+            call(src_dir, dst_dir, "*999999999*.txt")
         ]
 
     @pytest.mark.unit_test
     @pytest.mark.parametrize(
-        "state, expected",
+        "remote_files, downloaded_file",
         [
-            pytest.param("", (True, False, False), id="unknown-means-RUNNING"),
-            ("PENDING", (False, False, False)),
-            ("RUNNING", (True, False, False)),
-            ("CANCELLED", (True, True, True)),
-            ("CANCELLED by 123456", (True, True, True)),
-            ("TIMEOUT", (True, True, True)),
-            ("COMPLETED", (True, True, False)),
-            ("FAILED", (True, True, True)),
+            pytest.param(
+                # list of files in the remote server
+                [
+                    "finished_364ef7a8-e110-4a3c-a345-58640c5885b1_999999999.zip",
+                    "antares-err-123456789.txt",
+                    "antares-out-123456789.txt",
+                    "364ef7a8-e110-4a3c-a345-58640c5885b1_job_data_123456789.txt",
+                ],
+                # the downloaded file
+                "finished_364ef7a8-e110-4a3c-a345-58640c5885b1_999999999.zip",
+                # expected return value: list of downloaded files
+                id="nominal-case",
+            ),
+            pytest.param(
+                # list of files in the remote server
+                [
+                    "finished_XPANSION_364ef7a8-e110-4a3c-a345-58640c5885b1_999999999.zip",
+                    "antares-err-123456789.txt",
+                    "antares-out-123456789.txt",
+                    "364ef7a8-e110-4a3c-a345-58640c5885b1_job_data_123456789.txt",
+                ],
+                # the downloaded file
+                "finished_XPANSION_364ef7a8-e110-4a3c-a345-58640c5885b1_999999999.zip",
+                # expected return value: list of downloaded files
+                id="xpansion-case",
+            ),
+            pytest.param([], "", id="no-log-file-OK"),
+            pytest.param([], "", id="no-log-file-ERROR"),
         ],
     )
-    def test_get_job_state_flags__sacct_nominal_case(
-        self, remote_env, study, state, expected
+    def test_download_final_zip(
+        self,
+        remote_env,
+        study,
+        tmp_path,
+        remote_files: List[str],
+        downloaded_file: str,
     ):
-        """
-        Check that the "get_job_state_flags" method is correctly returning
-        the status flags ("started", "finished", and "with_error")
-        for a SLURM job in a specific state.
-        """
-        study.job_id = 42
-        args = [
-            "sacct",
-            f"--jobs={study.job_id}",
-            f"--name={study.name}",
-            "--format=JobID,JobName,State",
-            "--parsable2",
-            "--delimiter=,",
-            "--noheader",
-        ]
-        command = " ".join(shlex.quote(arg) for arg in args)
+        # noinspection PyUnusedLocal
+        def my_download_files(*args, **kwargs):
+            if downloaded_file:
+                tmp_path.joinpath(downloaded_file).touch()
+                return [tmp_path.joinpath(downloaded_file)]
+            return []
 
-        # noinspection SpellCheckingInspection
-        def execute_command_mock(cmd: str):
-            if cmd == f"scontrol show job {study.job_id}":
-                return "", "Invalid job id specified"
-            if cmd == command:
-                # the output of `sacct` should be: JobID,JobName,State
-                output = f"{study.job_id},{study.name},{state}" if state else ""
-                return output, None
-            assert False, f"Unknown command: {cmd}"
+        # given
+        study.job_id = 999999999
+        study.output_dir = str(tmp_path)
+        study.local_final_zipfile_path = ""  # not yet downloaded
+        remote_env.connection.download_files = my_download_files
 
-        remote_env.connection.execute_command = execute_command_mock
+        # when
+        actual = remote_env.download_final_zip(study)
 
-        actual = remote_env.get_job_state_flags(study)
+        # then
+        expected = tmp_path.joinpath(downloaded_file) if downloaded_file else None
         assert actual == expected
 
-    @pytest.mark.unit_test
-    def test_given_a_not_started_study_when_list_remote_logs_is_called_then_returns_empty_list(
-        self, remote_env, study
-    ):
-        # given
-        study.started = False
-        remote_env.connection.execute_command = mock.Mock(return_value=("", ""))
-
-        # when
-        output = remote_env._list_remote_logs(study)
-
-        # then
-        assert output == []
-
-    @pytest.mark.unit_test
-    def test_given_a_started_study_when_list_remote_logs_is_called_then_connection_execute_command_is_called_with_right_argument(
-        self, remote_env, study
-    ):
-        # given
-        study.job_id = 24
-        study.started = True
-        remote_env.connection.execute_command = mock.Mock(return_value=("", ""))
-        command = f"ls  {remote_env.remote_base_path}/*{study.job_id}*.txt"
-
-        # when
-        remote_env._list_remote_logs(study.job_id)
-
-        # then
-        remote_env.connection.execute_command.assert_called_once_with(command)
-
-    @pytest.mark.unit_test
-    def test_given_a_started_study_when_list_remote_logs_is_called_and_execute_command_produces_error_then_returns_empty_list(
-        self, remote_env, study
-    ):
-        # given
-        study.started = True
-        remote_env.connection.execute_command = mock.Mock(
-            return_value=("output", "error")
-        )
-
-        # when
-        output = remote_env._list_remote_logs(study)
-
-        # then
-        assert output == []
-
-    @pytest.mark.unit_test
-    def test_given_a_started_study_when_list_remote_logs_is_called_and_execute_command_produces_no_output_then_returns_empty_list(
-        self, remote_env, study
-    ):
-        # given
-        study.started = True
-        remote_env.connection.execute_command = mock.Mock(return_value=("", ""))
-
-        # when
-        output = remote_env._list_remote_logs(study)
-
-        # then
-        assert output == []
-
-    @pytest.mark.unit_test
-    def test_given_a_started_study_when_list_remote_logs_is_called_then_returns_not_empty_list(
-        self, remote_env, study
-    ):
-        # given
-        study.started = True
-        remote_env.connection.execute_command = mock.Mock(return_value=("output", ""))
-
-        # when
-        output = remote_env._list_remote_logs(study)
-
-        # then
-        assert output
-
-    @pytest.mark.unit_test
-    def test_given_a_study_when_download_logs_is_called_then_list_remote_logs_is_called(
-        self, remote_env, study
-    ):
-        # given
-        remote_env._list_remote_logs = mock.Mock(return_value=[])
-
-        # when
-        remote_env.download_logs(study)
-
-        # then
-        remote_env._list_remote_logs.assert_called_once_with(study.job_id)
-
-    @pytest.mark.unit_test
-    def test_given_an_empty_file_list_when_download_logs_is_called_then_connection_download_files_is_not_called(
-        self, remote_env, study
-    ):
-        # given
-        remote_env._list_remote_logs = mock.Mock(return_value=[])
-        remote_env.connection.download_file = mock.Mock()
-
-        # when
-        return_flag = remote_env.download_logs(study)
-
-        # then
-        remote_env.connection.download_file.assert_not_called()
-        assert return_flag is False
-
-    @pytest.mark.unit_test
-    def test_given_a_file_list_when_download_logs_is_called_then_connection_download_files_is_called_with_correct_arguments(
-        self, remote_env, study
-    ):
-        # given
-        study.job_log_dir = "job_log_dir"
-        file_path = "file"
-        remote_env._list_remote_logs = mock.Mock(return_value=[file_path])
-        remote_env.connection.download_file = mock.Mock()
-
-        src = f"{remote_env.remote_base_path}/{file_path}"
-        dst = str(Path(study.job_log_dir) / file_path)
-
-        # when
-        remote_env.download_logs(study)
-
-        # then
-        remote_env.connection.download_file.assert_called_once_with(src, dst)
-
-    @pytest.mark.unit_test
-    def test_given_a_not_clean_study_and_a_file_list_with_two_elements_when_download_logs_is_called_then_connection_download_files_is_called_twice(
-        self, remote_env, study
-    ):
-        # given
-        study.remote_server_is_clean = False
-        study.job_log_dir = "job_log_dir"
-        remote_env._list_remote_logs = mock.Mock(
-            return_value=["file_path", "file_path2"]
-        )
-        remote_env.connection.download_file = mock.Mock(return_value=True)
-
-        # when
-        return_flag = remote_env.download_logs(study)
-
-        # then
-        remote_env.connection.download_file.assert_called()
-        assert remote_env.connection.download_file.call_count == 2
-        assert return_flag is True
-
-    @pytest.mark.unit_test
-    def test_given_a_not_finished_study_when_check_final_zip_not_empty_then_returns_false(
-        self, remote_env, study
-    ):
-        # given
-        study.finished = False
-        final_zip_name = "final_zip_name"
-        # when
-        return_flag = remote_env.check_final_zip_not_empty(study, final_zip_name)
-        # then
-        assert return_flag is False
-
-    @pytest.mark.unit_test
-    def test_given_a_finished_study_when_check_final_zip_not_empty_then_check_file_not_empty_is_called(
-        self, remote_env, study
-    ):
-        # given
-        study.finished = True
-        final_zip_name = "final_zip_name"
-        remote_env.connection.check_file_not_empty = mock.Mock()
-        # when
-        remote_env.check_final_zip_not_empty(study, final_zip_name)
-        # then
-        remote_env.connection.check_file_not_empty.assert_called_once()
-
-    @pytest.mark.unit_test
-    def test_given_a_finished_study_with_empty_file_when_check_final_zip_not_empty_then_return_false(
-        self, remote_env, study
-    ):
-        # given
-        study.finished = True
-        final_zip_name = "final_zip_name"
-        remote_env.connection.check_file_not_empty = mock.Mock(return_value=False)
-        # when
-        return_flag = remote_env.check_final_zip_not_empty(study, final_zip_name)
-        # then
-        assert return_flag is False
-
-    @pytest.mark.unit_test
-    def test_given_a_finished_study_with_not_empty_file_when_check_final_zip_not_empty_then_return_true(
-        self, remote_env, study
-    ):
-        # given
-        study.finished = True
-        final_zip_name = "final_zip_name"
-        remote_env.connection.check_file_not_empty = mock.Mock(return_value=True)
-        # when
-        return_flag = remote_env.check_final_zip_not_empty(study, final_zip_name)
-        # then
-        assert return_flag is True
-
-    @pytest.mark.unit_test
-    def test_given_a_study_when_download_final_zip_is_called_then_check_final_zip_not_empty_is_called_with_correct_argument(
-        self, remote_env, study
-    ):
-        # given
-        study.path = "path"
-        study.job_id = 1234
-        final_zip_name = f"finished_{study.name}_{study.job_id}.zip"
-        remote_env.check_final_zip_not_empty = mock.Mock()
-        # when
-        remote_env.download_final_zip(study)
-        # then
-        remote_env.check_final_zip_not_empty.assert_called_once_with(
-            study, final_zip_name
-        )
-
-    @pytest.mark.unit_test
-    def test_given_a_study_with_empty_final_zip_when_download_final_zip_is_called_then_return_none(
-        self, study, remote_env
-    ):
-        # given
-        study.path = "path"
-        study.job_id = 1234
-        remote_env.connection.check_file_not_empty = mock.Mock(return_value=False)
-        # when
-        return_value = remote_env.download_final_zip(study)
-        # then
-        assert return_value is None
-
-    @pytest.mark.unit_test
-    def test_given_a_study_with_final_zip_already_downloaded_when_download_final_zip_is_called_then_return_local_final_zipfile_path(
-        self, study, remote_env
-    ):
-        # given
-        study.path = "path"
-        study.job_id = 1234
-        study.local_final_zipfile_path = "local_final_zipfile_path"
-        remote_env.check_final_zip_not_empty = mock.Mock(return_value=True)
-        # when
-        return_value = remote_env.download_final_zip(study)
-        # then
-        assert return_value == study.local_final_zipfile_path
-
-    @pytest.mark.unit_test
-    def test_given_a_study_with_final_zip_when_download_final_zip_is_called_then_download_file_is_called_with_correct_argument(
-        self, study, remote_env
-    ):
-        # given
-        study.finished = True
-        study.job_id = 1234
-        study.local_final_zipfile_path = ""
-        final_zip_name = f"finished_{Path(study.path).name}_{study.job_id}.zip"
-        remote_env.connection.check_file_not_empty = mock.Mock(return_value=True)
-        remote_env.connection.download_file = mock.Mock()
-        local_final_zipfile_path = str(Path(study.output_dir) / final_zip_name)
-        src = f"{remote_env.remote_base_path}/{final_zip_name}"
-        dst = local_final_zipfile_path
-        # when
-        remote_env.download_final_zip(study)
-        # then
-        remote_env.connection.download_file.assert_called_once_with(src, dst)
-
-    @pytest.mark.unit_test
-    def test_given_a_study_with_final_zip_when_download_final_zip_is_called_and_file_is_not_downloaded_then_returns_none(
-        self, study, remote_env
-    ):
-        # given
-        study.path = "path"
-        study.job_id = 1234
-        study.local_final_zipfile_path = ""
-        remote_env.check_file_not_empty = mock.Mock(return_value=True)
-        remote_env.connection.download_file = mock.Mock(return_value=False)
-        # when
-        return_value = remote_env.download_final_zip(study)
-        # then
-        assert return_value is None
-
-    @pytest.mark.unit_test
-    def test_given_a_study_with_final_zip_when_download_final_zip_is_called_and_file_is_downloaded_then_returns_local_zipfile_path(
-        self, study, remote_env
-    ):
-        # given
-        study.finished = True
-        study.job_id = 1234
-        final_zip_name = f"finished_{Path(study.path).name}_{study.job_id}.zip"
-        local_final_zipfile_path = str(Path(study.output_dir) / final_zip_name)
-        study.local_final_zipfile_path = ""
-        remote_env.connection.check_file_not_empty = mock.Mock(return_value=True)
-        remote_env.connection.download_file = mock.Mock(return_value=True)
-        # when
-        return_value = remote_env.download_final_zip(study)
-        # then
-        assert return_value == local_final_zipfile_path
-
     @pytest.mark.unit_test
     def test_given_a_study_with_input_zipfile_removed_when_remove_input_zipfile_then_return_true(
         self, remote_env, study
@@ -870,7 +598,7 @@ class TestRemoteEnvironmentWithSlurm:
             input_zipfile_name=Path(study.zipfile_path).name,
             time_limit=1,
             n_cpu=study.n_cpu,
-            antares_version=int(study.antares_version),
+            antares_version=study.antares_version,
             run_mode=study.run_mode,
             post_processing=study.post_processing,
             other_options="",
